/****************************************************************************
 *   Copyright (C) 2004 by Arboretum Systems, Inc.                          *
 *   Technical administrator: Alain Mazy, hav@mazy.be                       *
 *   Lead program designer: Georges Jaroslaw, gjaro@arboretum.com           *
 *                                                                          *
 *   HyperEngine-AV is a video, audio and text editor that can be used to   *
 *   record, import, edit, process and arrange together video, sound and    *
 *   text. These are all achieved in the program's free-form document       *
 *   window, with no limitations to the number of tracks.                   *
 *   The purpose of this program is to provide to users at all levels of    *
 *   expertise a readily accessible tool enabling them to create movies,    *
 *   slide shows or presentations.                                          *
 *                                                                          *
 *   HyperEngine-AV itself is free software. However, plug-ins that can be  *
 *   used as add-ons to HyperEngine-AV may or may not be free software, at  *
 *   the discretion of each plug-in developer and as specified by these     *
 *   plug-ins' respective licenses.                                         *
 *   You can redistribute HyperEngine-AV itself and/or modify it under the  *
 *   terms of the GNU General Public License as published by the Free       *
 *   Software Foundation; either version 2 of the License, or (at your      *
 *   option) any later version.                                             *
 *                                                                          *
 *   HyperEngine-AV is distributed in the hope that it will be useful, but  *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of             *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *   GNU General Public License for all applicable details.                 *
 *                                                                          *
 *   You should have received a copy of the GNU General Public License      *
 *   along with this program; if not, write to:                             *
 *   Free Software Foundation, Inc.,                                        *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.              *
 ****************************************************************************/
#import "MontageInterface.h"
#import "MIClipRep.h"

#ifndef ZzLocker_h
#include "ZzLocker.h"
#endif //ZzLocker_h

#import <Quicktime/quicktime.h>
#ifndef ArmeBasicTypes_h
#include "ArmeBasicTypes.h"
#endif ArmeBasicTypes_h

class TVideoObject;

enum {
GENERATE_THUMBNAILS,
GENERATE_IN_ADVANCE_CACHING,
};

struct RequestForDrawingThumbnail 
{
	ArmeTime					fThumbTime;
	bool						fNeedsRedraw;
	NSRect						fThumbRect;
};


@interface MIVideoClipRep : MIClipRep
{
	// thumbnails data
	//****************
	NSImage**		fThumbnailsArray;
	int				fNbThumbnailsInClip;

	NSSize			fSizeOfThumbImg;
	TVideoObject*	fVideoObject;

	// in advance caching stuffs
	//**************************
	ArmeTime			fStartTimeOfCurrentView;
	ArmeTime			fEndTimeOfCurrentView;
	ArmeTime			fThumbDurationOfCurrentView;
	ArmeTime 			fCurrentTimeForInAdvanceCaching;
	int					fCurrentStepForInAdvanceCaching;
	BOOL				fHasGeneratedCurrentViewCompletely;
	RequestForDrawingThumbnail fThumbRequest;
	
	// image caching stuffs
	//*********************
//	NSImage*		fCachedImage;
//	SInt64			fCachedImageStartTime;
//	SInt64			fCachedImageEndxTime;
//	BOOL            fStopImageUpdates;
	
}
- (id)initWithFrame:(NSRect)frame inTLC:(MITopLevelContainerRep*)theTLC;

- (void)refreshCachedBodyImage:(BOOL)createIfAbsent;

- (void)invalidateCachedImage;
//- (void)setEnableCachedImageUpdates:(BOOL)flag;
//- (void)updateCachedImageFrom:(SInt64)startTime to:(SInt64)endxTime wPixels:(float)imWidth hPixels:(float)imHeight;

- (void)drawBaseBodyRect:(NSRect)frameInDrawCoords clippedTo:(NSRect)clippingRect;
- (NSImage *)getImageRepAtTimeValue:(ArmeTime)aTime;
- (int)IsThumbnailAvailableForTime:(ArmeTime)aTime;

- (void)generateThumbnails;

- (void)generateInAdvanceCaching;

- (void)deleteThumbnailsArray;

- (MIObjectMouseHandling)handleMoreMouseTracking:(NSPoint)mouseLoc modifier:(unsigned int)modifier type:(NSEventType)type;

- (void) setEffectiveDuration:(ArmeTime)newDuration;
- (void) setBeginOffset:(ArmeTime)newOffset;
- (void) setEndOffset:(ArmeTime)newOffset;

@end


